@@ -9,8 +9,18 @@ sub foo {
     bar("bar", $_[1] - 2);
 }
 
+sub baz {
+    eval {
+        $DB::single = 1;
+
+        1; # to avoid an early return
+    }
+}
+
 foo("foo", 7);
 
+baz({ a => { b => 3 } }, [1, [2]]);
+
 $DB::single = 1;
 
 1; # to avoid the program terminating
