@@ -5,6 +5,8 @@ for (1 .. 5) {
 }
 # non brekeable line
 sub_break();
+arg_break(5);
+arg_break(15);
 
 sub should_break {
     return $i > 9
@@ -13,3 +15,7 @@ sub should_break {
 sub sub_break {
     $i = 0;
 }
+
+sub arg_break {
+    1; # to have a place to break
+}
